==> Jaspion-0.3.7.0.tar.gz: Jaspion-0.3.7.0/README.md <==
<h1 align="center">
  What is Jaspion?
</h1>

<p align="center">
  Jaspion is a python library designed to process events received from FreeSwitch via ESL.
</p>

<p align="center">
  <a href="https://travis-ci.com/Otoru/jaspion">
    <img alt="Build Status" src="https://travis-ci.com/Otoru/jaspion.svg?branch=master">
  </a>
  <a href="https://github.com/Otoru/jaspion/blob/master/LICENSE.md">
    <img alt="License" src="https://img.shields.io/github/license/otoru/jaspion.svg">
  </a>
  <a href="https://docs.python.org/3/whatsnew/3.7.html">
    <img alt=" Python Version" src="https://img.shields.io/pypi/pyversions/jaspion.svg">
  </a>
  <a href="https://pypi.org/project/Jaspion/">
    <img alt="PyPI - Status" src="https://img.shields.io/pypi/status/jaspion.svg">
  </a>
</p>

## What is FreeSwitch?

FreeSWITCH is a free and open-source application server for real-time communication, WebRTC, telecommunications, video and Voice over Internet Protocol (VoIP). Multiplatform, it runs on Linux, Windows, macOS and FreeBSD. It is used to build PBX systems, IVR services, videoconferencing with chat and screen sharing, wholesale least-cost routing, Session Border Controller (SBC) and embedded communication appliances. It has full support for encryption, ZRTP, DTLS, SIPS. It can act as a gateway between PSTN, SIP, WebRTC, and many other communication protocols. Its core library, libfreeswitch, can be embedded into other projects. It is licensed under the Mozilla Public License (MPL), a free software license.

By [wikipedia](https://en.wikipedia.org/wiki/FreeSWITCH).

## What is ESL?

ESL is a way to communicate with FreeSwitch. See more details [here](https://freeswitch.org/confluence/display/FREESWITCH/Event+Socket+Library).

## Docs

The project documentation is in [here](https://github.com/Otoru/jaspion/wiki).

## How to contribute?

If you are thinking of contributing in any way to the project, you will be very welcome.
Whether it's improving existing documentation, suggesting new features or running existing bugs, it's only by working together that the project will grow.
Do not forget to see our [Contributing Guide][2] and our [Code of Conduct][3] to always be aligned with the ideas of the project.

[2]: https://github.com/Otoru/jaspion/blob/master/CONTRIBUTING.md
[3]: https://github.com/Otoru/jaspion/blob/master/CODE_OF_CONDUCT.md

## Contributors

Will be welcome ❤️

## Author

| [<img src="https://avatars0.githubusercontent.com/u/26543872?v=3&s=115"><br><sub>@Otoru</sub>](https://github.com/Otoru) |
| :----------------------------------------------------------------------------------------------------------------------: |

==> Jaspion-0.3.7.1.tar.gz: Jaspion-0.3.7.1/README.md <==
<h1 align="center">
  What is Jaspion?
</h1>

<p align="center">
  Jaspion is a python library designed to process events received from FreeSwitch via ESL.
</p>

<p align="center">
  <a href="https://travis-ci.com/Otoru/jaspion">
    <img alt="Build Status" src="https://travis-ci.com/Otoru/jaspion.svg?branch=master">
  </a>
  <a href="https://github.com/Otoru/jaspion/blob/master/LICENSE.md">
    <img alt="License" src="https://img.shields.io/github/license/otoru/jaspion.svg">
  </a>
  <a href="https://docs.python.org/3/whatsnew/3.7.html">
    <img alt=" Python Version" src="https://img.shields.io/pypi/pyversions/jaspion.svg">
  </a>
  <a href="https://pypi.org/project/Jaspion/">
    <img alt="PyPI - Status" src="https://img.shields.io/pypi/status/jaspion.svg">
  </a>
</p>

## What is FreeSwitch?

FreeSWITCH is a free and open-source application server for real-time communication, WebRTC, telecommunications, video and Voice over Internet Protocol (VoIP). Multiplatform, it runs on Linux, Windows, macOS and FreeBSD. It is used to build PBX systems, IVR services, videoconferencing with chat and screen sharing, wholesale least-cost routing, Session Border Controller (SBC) and embedded communication appliances. It has full support for encryption, ZRTP, DTLS, SIPS. It can act as a gateway between PSTN, SIP, WebRTC, and many other communication protocols. Its core library, libfreeswitch, can be embedded into other projects. It is licensed under the Mozilla Public License (MPL), a free software license.

By [wikipedia](https://en.wikipedia.org/wiki/FreeSWITCH).

## What is ESL?

ESL is a way to communicate with FreeSwitch. See more details [here](https://freeswitch.org/confluence/display/FREESWITCH/Event+Socket+Library).

## Docs

The project documentation is in [here](https://otoru.github.io/jaspion/).

## How to contribute?

If you are thinking of contributing in any way to the project, you will be very welcome.
Whether it's improving existing documentation, suggesting new features or running existing bugs, it's only by working together that the project will grow.
Do not forget to see our [Contributing Guide][2] and our [Code of Conduct][3] to always be aligned with the ideas of the project.

[2]: https://github.com/Otoru/jaspion/blob/master/CONTRIBUTING.md
[3]: https://github.com/Otoru/jaspion/blob/master/CODE_OF_CONDUCT.md

## Contributors

Will be welcome ❤️

## Author

| [<img src="https://avatars0.githubusercontent.com/u/26543872?v=3&s=115"><br><sub>@Otoru</sub>](https://github.com/Otoru) |
| :----------------------------------------------------------------------------------------------------------------------: |
